# coding: utf-8
import web
import os
import re
from funciones import *
from web import form

#configuracion
web.config.debug = False

#direcciones utilizadas
urls = (
  '/', 'index',
  '/publicar/','publicar',
  '/buscar/(.*)','buscar',
  '/cuentas/','cuentas',
  '/img/(.*)', 'img'
)

#ubicacion del sitio template
render = web.template.render('templates/')

#forms
cuentasForm=form.Form(
    form.Textbox('nombre_persona',
                 form.notnull,
                 form.regexp("^[a-zA-z0-9 ]{1,40}$",
                             "Debe ser un caracter válido"),
                 size="40",
                 maxlength="40",
                 description="Tu Nombre"
                 ),
    form.Textbox('telefono',
                 form.notnull,
                 form.regexp("^\d{1,8}$","Debe ser un numero"),
                 size="8",
                 maxlength="8",
                 description="Tu teléfono"
                 ),
    form.Textbox('email',
                 form.notnull,
                 form.regexp("^[a-zA-z0-9 @.]{1,40}$",
                             "Debe ser un caracter válido"),
                 size="40",
                 maxlength="40",
                 description="Tu e-mail"
                 )
    )

publicForm=form.Form(
    form.Dropdown('persona',
                  [],
                  form.notnull,
                  description="Publicado por",
                  ),
    form.Textbox('nombre_articulo',
                 form.notnull,
                 form.regexp("^[a-zA-z0-9 ]{1,40}$",
                             "Debe ser un caracter válido"),
                 size="40",
                 maxlength="40",
                 description="Nombre Artículo"
                 ),
    form.Textarea('descripcion',
                  form.notnull,
                  form.regexp("^[a-zA-z0-9 .]{1,200}$",
                              "Debe ser un caracter válido"),
                  cols="50",
                  rows="3",
                  maxlength="200",
                  description="Descripción"
                  ),
    form.Textbox('precio',
                 form.notnull,
                 form.regexp("^\d{1,10}$","Debe ser un numero"),
                 description="Precio",
                 size="10",
                 maxlength="10"
                 ),
    form.Dropdown('tipo',
                  ['Accesorios',
                   'Animales',
                   'Computación',
                   'Deportes',
                   'Inmuebles',
                   'Videojuegos',
                   'Otro Tipo'],
                  value='Otro Tipo',
                  description="Tipo"
                  ),
    )


#pagina home
class index:
    def GET(self):
        ultimos=ultimos_articulos()
        recomendacion=recomendar_articulo()
        if recomendacion !={}:
            recomendacion["telefono"]="---"
            recomendacion["email"]="---"
            for data in obtener_cuentas():
                if data[0]==recomendacion["persona"]:
                    recomendacion["telefono"]=data[1]
                    recomendacion["email"]=data[2]
        return str(render.header("index"))+str(render.home(ultimos,recomendacion))+str(render.footer())

#pagina para crear cuentas
class cuentas:
    def GET(self):
        form=cuentasForm()
        return str(render.header("cuentas"))+str(render.formulario(form,"cuentas"))+str(render.footer())

    def POST(self):
        form=cuentasForm()
        if not form.validates():
            return str(render.header("cuentas"))+str(render.formulario(form,"cuentas"))+str(render.footer())
        else:
            persona=tuple([form.d.nombre_persona,form.d.telefono,form.d.email])
            crear_cuenta(persona)
            return str(render.header("cuentas"))+str(render.postcuentas(form))+str(render.footer())

#pagina para publicar articulos
class publicar:
    def GET(self):
        form=publicForm()
        nombres=list()
        for elem in obtener_cuentas():
            nombres.append(elem[0])
        form.persona.args=nombres
        return str(render.header("publicar"))+str(render.formulario(form,"publicar"))+str(render.footer())

    def POST(self):
        form=publicForm()
        nombres=list()
        for elem in obtener_cuentas():
            nombres.append(elem[0])
        form.persona.args=nombres
        
        if not form.validates():
            return str(render.header("publicar"))+str(render.formulario(form,"publicar"))+str(render.footer())
        else:
            articulo={
                "nombre": form.d.nombre_articulo,
                "descripcion": form.d.descripcion,
                "precio": int(form.d.precio),
                "tipo": form.d.tipo,
                "persona": form.d.persona
                }
            publicar_articulo(articulo)
            return str(render.header("publicar"))+str(render.postpublicar(form))+str(render.footer())

#pagina para buscar articulos
class buscar:
    def GET(self,name=None):
        if name:
            filtro=filtrar_articulos(name)
            resultado=resultado_busqueda(filtro)
            for result in resultado:
                result["telefono"]="---"
                result["email"]="---"
                for data in obtener_cuentas():
                    if data[0]==result["persona"]:
                        result["telefono"]=data[1]
                        result["email"]=data[2]                        
                for llave in result:
                    if llave in ["nombre","persona","descripcion"]:
                        result[llave]=palabras_clave(name,result[llave])
            
            return str(render.header("buscar"))+str(render.buscar(name,resultado))+str(render.footer())
        else:
            return str(render.header("buscar"))+str(render.buscar(name))+str(render.footer())

    def POST(self,name=None):
        post_input = web.input(_method='post')
        campo=post_input["campo"]
        redirect="/buscar/{0}"
        raise web.seeother(redirect.format(campo))

#permite imagenes en el servidor
class img:
    def GET(self,name):
        ext = name.split(".")[-1]

        cType = {
            "png":"img/png",
            "jpg":"img/jpeg",
            "gif":"img/gif",
            "ico":"img/x-icon"}

        if name in os.listdir('img'): 
            web.header("Content-Type", cType[ext])
            return open('img/%s'%name,"rb").read()
        else:
            raise web.notfound()

#pagina no encontrada
def notfound():
    return web.notfound(str(render.header("index"))+str(render.notfound())+str(render.footer()))

if __name__ == "__main__":
    app = web.application(urls, globals())
    app.notfound = notfound
    app.run()
    
